<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <meta name="generator" content="gallerize">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="stylesheet" href="style.css">
    {%- block head_additions %}{% endblock %}
    <title>{% if gallery_title is not none %}{{ gallery_title }}{% endif %}</title>
  </head>
  <body>

{%- block body required %}{% endblock %}

    <footer>
      <p>Generated by <a href="http://homework.nwsnet.de/releases/cc0e/#gallerize"><em>gallerize</em></a>.</p>
    </footer>

  </body>
</html>
