body {
  background-color: #dddddd;
  color: #333333;
  font-family: "Lucida Grande", Tahoma, Verdana, Arial, sans-serif;
  font-size: 100%;
  margin: 10px 40px;
  text-align: center;
  text-shadow: 0 1px 1px #ffffff;
}

a {
  color: #333333;
  text-decoration: none;
}

a:hover {
  text-decoration: underline;
}

header {
  margin: 2em 0;
}

header h1,
header p {
  font-family: Cambria, Georgia, "New Century Schoolbook", "Century Schoolbook L", "Times New Roman", serif;
  font-weight: bold;
  margin: 0;
  padding: 0;
}

header p {
  opacity: 0.5;
}

nav {
  margin: 1em 0 2em 0;
  opacity: 0.5;
}

nav:hover {
  opacity: 1;
}

nav ol {
  list-style: none;
  margin: 0;
  padding: 0;
}

nav ol li {
  display: inline-block;
  margin: 0 0.5em;
  padding: 0;
}

nav a[accesskey]:before {
  background-color: #cccccc;
  border: #aaaaaa outset 2px;
  content: attr(accesskey);
  font-family: monospace;
  font-size: 0.9em;
  margin-right: .5em;
  padding: 0 0.3em;
  text-transform: uppercase;
}

nav a[accesskey] {
  text-decoration: none;
}

nav a[accesskey]:hover span {
  text-decoration: underline;
}

ol.thumbnails {
  list-style: none;
  margin: 0;
  padding: 0;
}

ol.thumbnails li {
  float: left;
  margin: 0 8px 16px 8px;
  padding: 0;
}

figure {
  --hover-transition-duration: 150ms;
  height: 100%;
  margin: 0 auto;
  width: 100%;
}

figure a {
  display: block;
  position: relative;
}

figure a:before {
  background-color: #000000;
  content: "";
  display: block;
  height: 100%;
  left: 0;
  opacity: 0;
  overflow: visible;
  position: absolute;
  top: 0;
  transition: opacity var(--hover-transition-duration) ease-in;
  width: 100%;
  z-index: 2;
}

figure a:hover:before {
  display: block;
  opacity: 0.5;
}

figure img {
  border: #cccccc solid 2px;
  box-shadow: 3px 3px 4px #333333;
  display: block;
  margin: 0 auto;
  max-width: 100%;
  transition: border-color var(--hover-transition-duration) ease-out;
  z-index: 1;
}

figure a:hover img {
  border-color: #888888;
  transition: border-color var(--hover-transition-duration) ease-in;
}

figcaption {
  margin-top: 2em;
}

footer {
  clear: both;
  font-size: 0.8em;
  margin-top: 2em;
  opacity: 0.5;
  text-align: right;
}

footer:hover {
  opacity: 1;
}
